@@ -14,4 +14,8 @@ def copy(source, destination):
 
 @app.command("init")
 def init_mft():
-  bootstrap.start_mft()
\ No newline at end of file
+  bootstrap.start_mft()
+
+@app.command("stop")
+def init_mft():
+  bootstrap.stop_mft()
\ No newline at end of file
